/*
  Author:  Jonathan Bondzie, Dr. Chuck Yeung
           Lennard Gas Simulation Source

	   Copyright (C) 1999  Penn State University

	   This program is free software; you can redistribute it and/or
	   modify it under the terms of the GNU General Public License
	   as published by the Free Software Foundation;
	   
	   This program is distributed in the hope that it will be useful,
	   but WITHOUT ANY WARRANTY; without even the implied warranty of
	   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	   GNU General Public License for more details.
	   
	   You should have received a copy of the GNU General Public License
	   along with this program; if not, write to the Free Software
	   Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  
	   02111-1307, USA.

	   email jab341@psu.edu
*/

.TH PROGRAMFLOW
.SH Headers.h
	------> this contains two very important classes. The
Variables class and the Widgets class. Also included are the
prototypes of all the functions that have to be shared among other
sources. Each source has a list of functions under it's name. These
functions are the particular functions that are declared under that
particular source but shared among other sources.
.SH motifR.h
	-------> Contains the original headers included by DR. Chuck
Yeung. I may have included a header file or two.
.SH Lennard.cpp
	-------> Contains much of the mathematical calculations.
within lennard is the main() routine ( i.e. the whole program starts
in lennard.cpp). Within main() is the original instance (Variables*
ptr) of the Variables class. ptr contains the original address of the
Variables class all subseqent declerations of the Variables class have
to use the address of ptr in order to correctly change the working
copy of the variables stored in the Variables class. 
.SS "	"
.TP
-------->\fICommandLineParser(argc,...),\fP
is the commandline parsing routine. It takes argc,argv,ptr from main().
argc is however many command line arguments passed to the running
program (either out or lennard); argv is a character pointer to the
strings passed to the running program. Note CommandLineParser(arg,...)
has the original address of Variables, from main().
main()-->CommandLineParser(argc,argv,ptr).
.SS
.TP
-------->\fIInitializeArrays(ptr).\fP 
initializes all the dynamic arrays needed to run the simulation except
for the histogram array. Note this routine also deallocates all the
dynamic arrays.
main()-->InitializeArrays(ptr).
.SS
.TP
-------->\fIseedKiss((*ptr).seed1,...)\fP
 is the random generation function. This function does not directly
change the variables stored in the Variables class so only a copy is
sent to it. 
.SS
.TP
-------->\fImake_initial_state(ptr).\fP 
This routine generates the random positions, velocities and calls 
\fIfunction_Xple_check(pp,ptr),\fP which checks for overlaping
particles. Both these functions get the original address of the
Variables class from \fImain()\fP.\fI main()-->
make_initial_state(ptr)-->
function_Xple_check(pp,ptr).\fP From within
\fImake_initial_state(ptr)\fP  we call \fIMaxBoltzMemAlloc
(avg_velocity,ptr).\fP This routine takes the initials average
velocity and the Variables class address. It then determinse the
probable average velocity and then multiplies that by 300. This
value is used as the biggest index in the histogram
aray.\fImain()-->make_initial_state(ptr)
-->function_Xple_check(pp,ptr)-->MaxBoltzMemAlloc
(avg_velocity,ptr). \fP Note this is not the order that the program
flows; it's rather the order that the Variables class address is
being passed arround.

.SH Neighbour_List(ptr)
.SS "   "
.TP
--------->\fINeighbour_List(ptr)\fP 
This routine creates a neighbour list and during the time of update it
stores the previous values of the x,y positions.

.SH "IF NOGRAPHICS"
.SS NoGraphicsRoutine(ptr)
.TP
--------->\fINoGraphicsRoutine(ptr)\fP
This is the routine that called if -nographics option is specified on
the command line; in the initial start of the program. NoGraphics
calls \fIXmgrHistFunctionNoGraphics(ptr)\fP if the -graph option is
specified on the command line. \fIXmgrHistFunctionNoGraphics()\fP routine
gets the original address of the Variables class directly from
\fINoGraphicsRoutine()\fP. It will calculate the normalized histogram
containing the Maxwell Bolzman distribution. \fINoGraphicsRoutine()\fP also
calls the \fIDumpQuantities(ptr,...)\fP routine which dumps the phisical
quantities of the running program to the tty of the running program.
\fImain()-->NoGraphicsRoutine(ptr,...)
-->XmgrHistFunctionNoGraphics(ptr)-->kinetic_energy_calc(ptr)-->
potential_energy_calc(ptr)-->DumpQuantities(ptr...).\fP
.SH if(!nographics)
.SS "IF THE PROGRAM IS TO RUN GRAPHICS "
.TP
--------->\fISetupInitialGraphics(argc, argv,ptr);\fP
This routine only sets up the initial graphics needed to run the
simulations. Because passing pointers to classes as XtPointers is a
very painfull process I have declared a global copy of the
Varibles* ptr. This copy of the variables class gets used by the
kinetic energy callback routines. Note althoug \fRVariables* ptr\fP is
global  it's local only to \fISetupInitialGraphics()\fP. The global address
of the instance of the Variables class declared in
\fISetupInitialGraphics()\fP  is set equal to the original address of the
Variables class, which is passed from \fImain()\fP to
\fISetupInitialGraphics()\fP.  Form within \fISetupInitialGraphics()\fP the address
of the original copy of the Variables class is passed to
\fIFunction(ptr)\fP. This is the link between the Variables class and the
source file \fBFormCreationFunction.cpp\fP.
\fImain()-->SetupInitialGraphics(argc,argv,ptr)
|\fB-->link Variables* ptr and
FormCreationFunction.cpp\fP\fI-->Function(ptr).\fP
.SH XtAppAddWorkProc(dgr_app_context,(XtWorkProc)work_proc,ptr)
.SS \fIwork_proc(ptr)\fP
.TP
This routine is the work procedure function. It waits for user events
as reported by the X server. If there are no on-going events it just
executes a set of functions. One of these functions is
\fIDrawCircles(ptr)\fP. This routine draws the circles of the particles
using thier x,y coordinates. It also updates the text fields that were
setup by \fISetupInitialGraphics().\fP
\fImain()-->work_proc(ptr)-->DrawCircles(ptr)-->
kinetic_energy_calc(ptr)-->
potential_energy_calc(ptr)-->update_positions(ptr).\fP
.SH Variables* ptr
.SS "SHARED AMONG SOURCE FILES"
.TP
--------->\fImain()\fP-->\fBlennard.cpp\fP-->\fISetupInitialGraphics()
\fP-->\fBSetupInitialGraphics.cpp\fP-->\fINoGraphicsRoutine()\fP-->
\fBNoGraphicsRoutine.cpp\fP-->\fIDrawCircles()\fP-->
\fBDrawCircles.cpp\fP-->\fIFunction()\fP-->\fBFormCreationFunction.cpp\fP

.SH Widgets Class
.SS SetupInitialGraphics
.TP
The original address of the Widgets class is instantiated in
\fISetupInitialGraphics()\fP as a global variable. The reason for
declaring the Widgets class global to \fISetupInitialGraphics()\fP is
that the link between the source files that share the widgets is very
weak. In order to share the widgets I had to create a function
\fIReturnClassAddress(Widgets*wptr),\fP which returns the address of
the Widgets class address to any source file that might need to use a
shared widget. Note once more that though the initial instance of the
Widgets class it global, it's only local to
\fISetupInitialGraphics()\fP. The Widgets class is only used within
\fBFormCreationFunction.cpp\fP and \fBDrawCircles.cpp\fP, well and
\fBlennard.cpp\fP,but only once. 
.SS "HOW THE WIDGETS CLASS IS SHARED AMONG FUNCTIONS"
.TP
\fISetupInitialGraphics()-->ReturnClassAddress()-->
FormCreationFunction()-->DrawCircles()-->ShrinkTheBox().\fP

.SS "HOW THE WIDGETS CLASS IS SHARED AMONG SOURCES "
.TP
\fISetupInitialGraphics()\fP-->\fBSetupInitialGraphics.cpp\fP-->
\fIReturnClassAddress()\fP-->\fIFormCreationFunction()\fP-->
\fBFormCreationFunction.cpp\fP-->\fIReturnClassAddress()\fP-->
\fIDrawCircles()\fP-->\fBDrawCircles.cpp\fP-->
\fIReturnClassAddress()\fP-->\fIShrinkTheBox()\fP-->\fBlennard.cpp\fP
.SH AUTHORS \fB DR. Chuck Yeung, Jonathan Archibold Bondzie\fP